# Game targeting model
## Status
### Test & Publishing 
[![Python package](https://github.com/KentVejrupMadsen/gv-targeting-model/actions/workflows/testing.yml/badge.svg)](https://github.com/KentVejrupMadsen/gv-targeting-model/actions/workflows/testing.yml)
[![Upload Python Package](https://github.com/KentVejrupMadsen/gv-targeting-model/actions/workflows/publish.yml/badge.svg)](https://github.com/KentVejrupMadsen/gv-targeting-model/actions/workflows/publish.yml)

### Code State
[![CodeScene Code Health](https://codescene.io/projects/40297/status-badges/code-health)](https://codescene.io/projects/40297)
[![CodeScene System Mastery](https://codescene.io/projects/40297/status-badges/system-mastery)](https://codescene.io/projects/40297)
